| Title: | Stock Database Web Services |
|---|---|
| Description: | R interface to access the web services of the ICES Stock Database <https://sd.ices.dk>. |
| Authors: | Colin Millar [aut, cre], Scott Large [aut], Arni Magnusson [aut] |
| Maintainer: | Colin Millar <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 2.1.0 |
| Built: | 2026-05-24 10:10:56 UTC |
| Source: | https://github.com/ices-tools-prod/icesSD |
R interface to access the web services of the ICES Stock Database.
Get dataset:
getSD |
full stock list, with filtering by stock and year |
Show on screen:
showStock |
one stock, in a readable format |
Colin Millar, Scott Large, and Arni Magnusson.
ICES Stock Database: https://sd.ices.dk.
ICES Stock Database web services: https://sd.ices.dk/services/.
Useful links:
Report bugs at https://github.com/ices-tools-prod/icesSD/issues
Get stock list data such as stock code, expert group, assessment type, etc.
getSD(stock = NULL, year = NULL)getSD(stock = NULL, year = NULL)
stock |
the stock code, e.g. cod.27.47d20. |
year |
the active year of the stock list, e.g. 2016, or NULL to get the most recent year available. |
A data frame.
icesSD-package gives an overview of the package.
## Not run: sddata <- getSD() cod <- getSD(stock = "cod.27.47d20") cod22 <- getSD(stock = "cod.27.47d20", year = 2022) y2022 <- getSD(year = 2022) ## End(Not run)## Not run: sddata <- getSD() cod <- getSD(stock = "cod.27.47d20") cod22 <- getSD(stock = "cod.27.47d20", year = 2022) y2022 <- getSD(year = 2022) ## End(Not run)
utility to build a url with optional query arguments
sd_api(service, ...)sd_api(service, ...)
service |
the name of the service |
... |
name arguments will be added as queries |
a complete url as a character string
sd_api("hi", bye = 21) sd_api("odata4/StockListDWs4")sd_api("hi", bye = 21) sd_api("odata4/StockListDWs4")
Show stock list data for one stock, in a readable format.
showStock(stock, year = NULL)showStock(stock, year = NULL)
stock |
the stock code, e.g. |
year |
the active year of the stock listing, e.g. |
If year = NULL then the newest year is shown.
A single-row data frame, shown on the screen with print.simple.list.
The stock list data specify the expert group, advice group, assessment type, etc.
getSD is the underlying function to get the stock list data.
icesSD-package gives an overview of the package.
## Not run: showStock("cod.27.7a", 2023) showStock("cod.27.7a", 2024) ## End(Not run)## Not run: showStock("cod.27.7a", 2023) showStock("cod.27.7a", 2024) ## End(Not run)